@@ -75,6 +75,38 @@ size_allocate (PanelApplet  *applet,
     drive_list_set_panel_size (drive_list, size);
 }
 
+static void
+change_background (PanelApplet               *applet,
+		   PanelAppletBackgroundType  type,
+		   GdkColor                  *colour,
+		   GdkPixmap                 *pixmap)
+{
+    GtkRcStyle *rc_style;
+    GtkStyle *style;
+
+    /* reset style */
+    gtk_widget_set_style (GTK_WIDGET (applet), NULL);
+    rc_style = gtk_rc_style_new ();
+    gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
+    g_object_unref (rc_style);
+
+    switch (type) {
+    case PANEL_NO_BACKGROUND:
+	break;
+    case PANEL_COLOR_BACKGROUND:
+	gtk_widget_modify_bg (GTK_WIDGET (applet),
+			      GTK_STATE_NORMAL, colour);
+	break;
+    case PANEL_PIXMAP_BACKGROUND:
+	style = gtk_style_copy (GTK_WIDGET (applet)->style);
+	if (style->bg_pixmap[GTK_STATE_NORMAL])
+	    g_object_unref (style->bg_pixmap[GTK_STATE_NORMAL]);
+	style->bg_pixmap[GTK_STATE_NORMAL] = g_object_ref (pixmap);
+	gtk_widget_set_style (GTK_WIDGET (applet), style);
+	break;
+    }
+}
+
 static void
 display_about_dialog (BonoboUIComponent *uic,
 		      DriveList *drive_list,
@@ -161,6 +193,8 @@ applet_factory (PanelApplet *applet,
 				 G_CALLBACK (change_orient), drive_list, 0);
 	g_signal_connect_object (applet, "size_allocate",
 				 G_CALLBACK (size_allocate), drive_list, 0);
+	g_signal_connect (applet, "change_background",
+			  G_CALLBACK (change_background), NULL);
 
 	/* set initial state */
 	change_orient (applet,
