@@ -124,6 +124,16 @@ GSwitchItAppletReinitUi (GSwitchItApplet * sia)
 	}
 }
 
+static void
+GSwitchItConfigChanged (GConfClient * client,
+			guint cnxn_id,
+			GConfEntry * entry, GSwitchItApplet * sia)
+{
+	GSwitchItConfigLoad (&sia->config);
+	GSwitchItConfigActivate (&sia->config);
+	GSwitchItAppletReinitUi (sia);
+}
+
 static void
 GSwitchItAppletConfigChanged (GConfClient * client,
 			      guint cnxn_id,
@@ -675,14 +685,13 @@ GSwitchItAppletStartListen (GSwitchItApplet * sia)
 	gdk_window_add_filter (gdk_get_default_root_window (),
 			       (GdkFilterFunc) GSwitchItAppletFilterXEvt,
 			       sia);
-	XklStartListen (XKLL_MANAGE_WINDOW_STATES);
+	XklStartListen (XKLL_TRACK_KEYBOARD_STATE);
 }
 
 static void
 GSwitchItAppletStopListen (GSwitchItApplet * sia)
 {
 	XklStopListen ();
-/* !! no client message filter removal in gnome 2.2 */
 	gdk_window_remove_filter (NULL, (GdkFilterFunc)
 				  GSwitchItAppletFilterXEvt, sia);
 	gdk_window_remove_filter
@@ -756,6 +765,8 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 	GSwitchItKbdConfigInit (&sia->kbdConfig, confClient);
 	GSwitchItAppletConfigInit (&sia->appletConfig, confClient);
 	GSwitchItPluginManagerInit (&sia->pluginManager);
+	GSwitchItConfigLoad (&sia->config);
+	GSwitchItConfigActivate (&sia->config);
 	GSwitchItKbdConfigLoadCurrent (&sia->kbdConfig);
 	GSwitchItAppletConfigLoad (&sia->appletConfig);
 	GSwitchItAppletConfigUpdateImages (&sia->appletConfig,
@@ -766,6 +777,10 @@ GSwitchItAppletInit (GSwitchItApplet * sia, PanelApplet * applet)
 						  &sia->pluginContainer,
 						  sia->appletConfig.
 						  enabledPlugins);
+	GSwitchItConfigStartListen (&sia->config,
+				    (GConfClientNotifyFunc)
+				    GSwitchItConfigChanged,
+				    sia);
 	GSwitchItAppletConfigStartListen (&sia->appletConfig,
 					  (GConfClientNotifyFunc)
 					  GSwitchItAppletConfigChanged,
@@ -800,6 +815,7 @@ GSwitchItAppletTerm (PanelApplet * applet, GSwitchItApplet * sia)
 	terminatedOnce = TRUE;
 	XklDebug (100, "Starting the applet shutdown process\n");
 	GSwitchItAppletStopListen (sia);
+	GSwitchItConfigStopListen (&sia->config);
 	GSwitchItAppletConfigStopListen (&sia->appletConfig);
 	XklRegisterStateCallback (NULL, NULL);
 	XklRegisterConfigCallback (NULL, NULL);
